<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Form\Extension;

use FriendsOfSylius\SyliusImportExportPlugin\Form\ImportType;
use FriendsOfSylius\SyliusImportExportPlugin\Importer\ImporterRegistry;
use Symfony\Component\Form\AbstractTypeExtension;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\FormBuilderInterface;

class ImportTypeExtension extends AbstractTypeExtension
{
    private ImporterRegistry $importerRegistry;

    public function __construct(ImporterRegistry $importerRegistry)
    {
        $this->importerRegistry = $importerRegistry;
    }

    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->remove('format')
            ->add('format', ChoiceType::class, [
                'choices' => $this->buildChoices($options),
                'expanded' => false,
                'multiple' => false,
                'required' => true,
            ])
        ;
    }

    private function buildChoices(array $options): array
    {
        /** @var string $importerType */
        $importerType = $options['importer_type'];

        $choices = [];
        if ($this->importerRegistry->has(ImporterRegistry::buildServiceName($importerType, 'csv'))) {
            $choices['CSV'] = 'csv';
        }
        if ($this->importerRegistry->has(ImporterRegistry::buildServiceName($importerType, 'xlsx'))) {
            $choices['Excel'] = 'xlsx';
        }
        if ($this->importerRegistry->has(ImporterRegistry::buildServiceName($importerType, 'txt'))) {
            $choices['TXT'] = 'txt';
        }
        $choices['JSON'] = 'json';

        return $choices;
    }

    public static function getExtendedTypes(): iterable
    {
        return [ImportType::class];
    }
}
