<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\ShippingMethod;

use Sylius\Component\Core\Model\ShippingMethodInterface;
use Sylius\Component\Shipping\Model\ShippingMethodRule;
use Sylius\Component\Shipping\Model\ShippingMethodRuleInterface;

trait ShippingMethodRuleTrait
{
    protected function addRule(ShippingMethodInterface $shippingMethod, string $type, array $configuration): void
    {
        $rule = $this->getRule($shippingMethod, $type);
        if (null === $rule) {
            $rule = new ShippingMethodRule();
        }
        $rule->setType($type);
        $rule->setConfiguration(array_replace_recursive($rule->getConfiguration(), $configuration));
        $shippingMethod->addRule($rule);
    }

    protected function getRule(ShippingMethodInterface $shippingMethod, string $rule): ?ShippingMethodRuleInterface
    {
        $rules = $shippingMethod->getRules()->filter(function (ShippingMethodRuleInterface $shippingMethodRule) use ($rule): bool {
            return $shippingMethodRule->getType() === $rule;
        });

        if ($rules->count() <= 0) {
            return null;
        }

        return $rules->first();
    }
}
